==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/PartAssociation.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STORELOCATION;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STORELOCATION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="is_bylot" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partid",
    "storelocation"
})
@XmlRootElement(name = "PartAssociation")
public class PartAssociation {

    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "STORELOCATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected STORELOCATION storelocation;
    @XmlAttribute(name = "is_bylot")
    protected String is_Bylot;

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the storelocation property.
     * 
     * @return
     *     possible object is
     *     {@link STORELOCATION }
     *     
     */
    public STORELOCATION getSTORELOCATION() {
        return storelocation;
    }

    /**
     * Sets the value of the storelocation property.
     * 
     * @param value
     *     allowed object is
     *     {@link STORELOCATION }
     *     
     */
    public void setSTORELOCATION(STORELOCATION value) {
        this.storelocation = value;
    }

    /**
     * Gets the value of the is_Bylot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Bylot() {
        return is_Bylot;
    }

    /**
     * Sets the value of the is_Bylot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Bylot(String value) {
        this.is_Bylot = value;
    }

}

==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/PartAssociation.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STORELOCATION;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STORELOCATION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="is_bylot" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partid",
    "storelocation"
})
@XmlRootElement(name = "PartAssociation")
public class PartAssociation {

    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "STORELOCATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected STORELOCATION storelocation;
    @XmlAttribute(name = "is_bylot")
    protected String is_Bylot;

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété storelocation.
     * 
     * @return
     *     possible object is
     *     {@link STORELOCATION }
     *     
     */
    public STORELOCATION getSTORELOCATION() {
        return storelocation;
    }

    /**
     * Définit la valeur de la propriété storelocation.
     * 
     * @param value
     *     allowed object is
     *     {@link STORELOCATION }
     *     
     */
    public void setSTORELOCATION(STORELOCATION value) {
        this.storelocation = value;
    }

    /**
     * Obtient la valeur de la propriété is_Bylot.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Bylot() {
        return is_Bylot;
    }

    /**
     * Définit la valeur de la propriété is_Bylot.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Bylot(String value) {
        this.is_Bylot = value;
    }

}
